Crate kcr_litmuschaos_io

Crate kcr_litmuschaos_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the litmuschaos.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

litmuschaos.io/v1alpha1

  • ChaosEngine
  • ChaosExperiment
  • ChaosResult

Modules

v1alpha1